==> nocc-1.9.5.txz: usr/local/www/nocc/lang/diq.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: $
 */
/** Zazaki (Zazaki)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Erdemaslancan
 * @author Gorizon
 * @author Marmase
 * @author Mirzali
 */

$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'cay karberi veng meverde';
$err_passwd_empty = 'cay parola veng meverde';
$alt_delete = 'mesacane weçineya besterne';
$alt_delete_one = 'Mesaci besterne';
$alt_new_msg = 'Mesaco newe';
$alt_reply = 'Nuştekari re cewab';
$alt_reply_all = 'Heminre cewab bıdı';
$alt_forward = 'Raver';
$alt_next = 'Bahdoyên';
$alt_prev = 'Verên';
$title_next_page = 'Pela bahdoyên';
$title_prev_page = 'Pela verên';
$title_next_msg = 'Mesaco bahdoyên';
$title_prev_msg = 'Mesaco verên';
$html_theme_label = 'Tema:';
$html_welcome = '%1$s\'re şıma Weş amey';
$html_login = 'Cıkewtış';
$html_user_label = 'Karber';
$html_passwd_label = 'Parola:';
$html_submit = 'deqew';
$html_help = 'Peşti';
$html_server_label = 'Waster';
$html_wrong = 'Namey karberi yana parola çewta';
$html_retry = 'fına bıcerbni';
$html_remember = 'Mı biya xo viri';
$html_lang_label = 'Zıwan:';
$html_preferences = 'Sazi';
$html_full_name_label = 'Name pêro:';
$html_reply_to = 'Cıwabê cı';
$html_reply_to_label = 'Cıwabê cı';
$html_reply_leadin_label = 'Cewab dayış';
$html_folders = 'Gale';
$html_folder_rename = 'Babetna name ke';
$html_folder_create = 'Galeyo newe vırazı';
$html_folder_delete = 'Bestere';
$html_filter_remove = 'Bestere';
$html_and = 'u';
$html_new_msg_in = 'tede mesacê newey';
$html_or = 'ya zi';
$html_move = 'Bere';
$html_copy = 'Kopya ke';
$html_gotopage = 'Şo pele';
$html_gotofolder = 'Şo klasor';
$html_other_folders = 'listey gali';
$html_page = 'Pele';
$html_of = 'dı';
$html_view_header = 'Sernami basnı';
$html_remove_header = 'Sernami bınımnı';
$html_inbox = 'Dora ameya';
$html_new_msg = 'Bınusne';
$html_reply = 'Cewab bıde';
$html_reply_short = 'Cwb:';
$html_reply_all = 'Hemın re cewab';
$html_forward = 'Raver';
$html_forward_short = 'Fwd:';
$html_delete = 'Bestere';
$html_new = 'Newe';
$html_mark = 'Bestere';
$html_att_label = 'Çol';
$html_atts_label = 'Çoli';
$html_unknown = '[Ne sılasneno]';
$html_part_x = 'Lete %s';
$html_attach = 'De ke';
$html_from = 'Kêra';
$html_from_label = 'Kêra:';
$html_subject = 'Mewzu';
$html_subject_label = 'Mewzu:';
$html_date = 'Deme';
$html_date_label = 'Deme:';
$html_sent_label = 'Rışna:';
$html_wrote = 'Nusneya';
$html_quote_wrote = '%1$s de,  embaz %2$s nusna:';
$html_size = 'Gırdiye';
$html_totalsize = 'Ebad pêro';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bayti';
$html_filename = 'Nameyê dosya';
$html_to = 'Kêra';
$html_to_label = 'Kami rê:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Mewzu çıniyo';
$html_send = 'Bırışe';
$html_cancel = 'Bıtexelne';
$html_no_mail = 'Mesac çıniyo.';
$html_logout = 'Veciyayış';
$html_msg = 'Mesac';
$html_msgs = 'Mesaci';
$html_priority = 'Sıfteyıniye';
$html_priority_label = 'Sıfteyıniye:';
$html_lowest = 'Tewr kemi';
$html_low = 'Kemi';
$html_normal = 'Normal';
$html_high = 'Berz';
$html_highest = 'Tewr berz';
$html_flagged = 'Nışan biyo';
$html_spam = 'Spam';
$html_select = 'Weçine';
$html_add = 'Cı ke';
$html_contacts = '%1$s Kes';
$html_modify = 'Bıvurne';
$html_back = 'Peyser';
$html_contact_add = 'Keso newe cı ke';
$html_contact_first = 'Nameyo sıfteyên';
$html_contact_last = 'Nameyo peyên';
$html_contact_nick = 'leqebe';
$html_contact_mail = 'E-poste';
$html_contact_list = 'Lista kesanê %1$s';
$html_contact_del = 'Lista kesan ra';
$html_contact_count = '%1$d Kesi';
$html_contact_err1 = 'Amarê kesanê tewr zêdeyan "%1$d"';
$html_down_mail = 'War ke';
$original_msg = '-- Mesaco Oricinal --';
$html_search = 'Cı geyre';
$html_new_session = 'Ronıştışo bahdoyên';
$html_fd_filename = '%1$s ame war';
$html_fd_filesize = 'ebadê %1$d dero';
$html_fd_skipcount = 'be %1$d eposteyan ra';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/diq.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: $
 */
/** Zazaki (Zazaki)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Erdemaslancan
 * @author Gorizon
 * @author Marmase
 * @author Mirzali
 */

$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'cay karberi veng meverde';
$err_passwd_empty = 'cay parola veng meverde';
$alt_delete = 'mesacane weçineya besterne';
$alt_delete_one = 'Mesaci besterne';
$alt_new_msg = 'Mesaco newe';
$alt_reply = 'Nuştekari re cewab';
$alt_reply_all = 'Heminre cewab bıdı';
$alt_forward = 'Raver';
$alt_next = 'Bahdoyên';
$alt_prev = 'Verên';
$title_next_page = 'Pela bahdoyên';
$title_prev_page = 'Pela verên';
$title_next_msg = 'Mesaco bahdoyên';
$title_prev_msg = 'Mesaco verên';
$html_theme_label = 'Tema:';
$html_welcome = '%1$s\'re şıma Weş amey';
$html_login = 'Cıkewtış';
$html_user_label = 'Karber';
$html_passwd_label = 'Parola:';
$html_submit = 'deqew';
$html_help = 'Peşti';
$html_server_label = 'Waster';
$html_wrong = 'Nameyê karberi ya zi parola ğeleta';
$html_retry = 'fına bıcerbni';
$html_remember = 'Mı biya xo viri';
$html_lang_label = 'Zıwan:';
$html_preferences = 'Sazi';
$html_full_name_label = 'Name pêro:';
$html_reply_to = 'Cıwabê cı';
$html_reply_to_label = 'Cıwabê cı';
$html_reply_leadin_label = 'Cewab dayış';
$html_folders = 'Gale';
$html_folder_rename = 'Babetna name ke';
$html_folder_create = 'Galeyo newe vırazı';
$html_folder_delete = 'Bestere';
$html_filter_remove = 'Bestere';
$html_and = 'u';
$html_new_msg_in = 'Mesacê neweyê ke tederê';
$html_or = 'ya zi';
$html_move = 'Bere';
$html_copy = 'Kopya ke';
$html_gotopage = 'Şo pele';
$html_gotofolder = 'Şo klasor';
$html_other_folders = 'listey gali';
$html_page = 'Pele';
$html_of = 'dı';
$html_view_header = 'Sernami basnı';
$html_remove_header = 'Sernami bınımnı';
$html_inbox = 'Dora ameya';
$html_new_msg = 'Bınusne';
$html_reply = 'Cewab bıde';
$html_reply_short = 'Cwb:';
$html_reply_all = 'Hemın re cewab';
$html_forward = 'Raver';
$html_forward_short = 'Fwd:';
$html_delete = 'Bestere';
$html_new = 'Newe';
$html_mark = 'Bestere';
$html_att_label = 'Çol';
$html_atts_label = 'Çoli';
$html_unknown = '[Ne sılasneno]';
$html_part_x = 'Lete %s';
$html_attach = 'De ke';
$html_from = 'Kêra';
$html_from_label = 'Kêra:';
$html_subject = 'Mewzu';
$html_subject_label = 'Mewzu:';
$html_date = 'Dem';
$html_date_label = 'Dem:';
$html_sent_label = 'Rışna:';
$html_wrote = 'Nusneya';
$html_quote_wrote = '%1$s de,  embaz %2$s nusna:';
$html_size = 'Gırdiye';
$html_totalsize = 'Ebad pêro';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bayti';
$html_filename = 'Nameyê dosya';
$html_to = 'Kêra';
$html_to_label = 'Kami rê:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Mewzu çıniyo';
$html_send = 'Bırışe';
$html_cancel = 'Bıtexelne';
$html_no_mail = 'Mesac çıniyo.';
$html_logout = 'Veciyayış';
$html_msg = 'Mesac';
$html_msgs = 'Mesaci';
$html_priority = 'Sıfteyıniye';
$html_priority_label = 'Sıfteyıniye:';
$html_lowest = 'Tewr kemi';
$html_low = 'Kemi';
$html_normal = 'Normal';
$html_high = 'Berz';
$html_highest = 'Tewr berz';
$html_flagged = 'Nışan biyo';
$html_spam = 'Spam';
$html_select = 'Weçine';
$html_add = 'Cı ke';
$html_contacts = '%1$s Kes';
$html_modify = 'Bıvurne';
$html_back = 'Peyser';
$html_contact_add = 'Keso newe cı ke';
$html_contact_first = 'Nameyo sıfteyên';
$html_contact_last = 'Nameyo peyên';
$html_contact_nick = 'leqebe';
$html_contact_mail = 'E-poste';
$html_contact_list = 'Lista kesanê %1$s';
$html_contact_del = 'Lista kesan ra';
$html_contact_count = '%1$d Kesi';
$html_contact_err1 = 'Amarê kesanê tewr zêdeyan "%1$d"';
$html_down_mail = 'War ke';
$original_msg = '-- Mesaco Oricinal --';
$html_search = 'Cı geyre';
$html_new_session = 'Ronıştışo bahdoyên';
$html_fd_filename = '%1$s ame war';
$html_fd_filesize = 'ebadê %1$d dero';
$html_fd_skipcount = 'be %1$d eposteyan ra';
